Building Blocks of a DR Model
======================================

Short intro

.. _model:

Model
-----

Explain models

.. _relations:

Relations
---------

Explain relations

.. _transforms:

Relation Transforms
-------------------

Explain transforms

.. _loss:

Losses
------

Explain Losses

.. _training:

Training Phases
---------------

Explain training phases

